@@ -2,6 +2,7 @@ import argparse
 from typing import Optional
 
 import annofabcli.annotation.change_annotation_attributes
+import annofabcli.annotation.change_annotation_attributes_per_annotation
 import annofabcli.annotation.change_annotation_properties
 import annofabcli.annotation.copy_annotation
 import annofabcli.annotation.delete_annotation
@@ -10,16 +11,18 @@ import annofabcli.annotation.dump_annotation
 import annofabcli.annotation.import_annotation
 import annofabcli.annotation.list_annotation
 import annofabcli.annotation.list_annotation_count
+import annofabcli.annotation.merge_segmentation
+import annofabcli.annotation.remove_segmentation_overlap
 import annofabcli.annotation.restore_annotation
 import annofabcli.common.cli
 
 
-def parse_args(parser: argparse.ArgumentParser):
-
+def parse_args(parser: argparse.ArgumentParser) -> None:
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
     annofabcli.annotation.change_annotation_attributes.add_parser(subparsers)
+    annofabcli.annotation.change_annotation_attributes_per_annotation.add_parser(subparsers)
     annofabcli.annotation.change_annotation_properties.add_parser(subparsers)
     annofabcli.annotation.copy_annotation.add_parser(subparsers)
     annofabcli.annotation.delete_annotation.add_parser(subparsers)
@@ -28,6 +31,8 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.annotation.import_annotation.add_parser(subparsers)
     annofabcli.annotation.list_annotation.add_parser(subparsers)
     annofabcli.annotation.list_annotation_count.add_parser(subparsers)
+    annofabcli.annotation.merge_segmentation.add_parser(subparsers)
+    annofabcli.annotation.remove_segmentation_overlap.add_parser(subparsers)
     annofabcli.annotation.restore_annotation.add_parser(subparsers)
 
 
@@ -36,8 +41,6 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     subcommand_help = "アノテーション関係のサブコマンド"
     description = "アノテーション関係のサブコマンド"
 
-    parser = annofabcli.common.cli.add_parser(
-        subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
-    )
+    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, is_subcommand=False)
     parse_args(parser)
     return parser
