@@ -1,13 +1,12 @@
 from __future__ import annotations
 
 import enum
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 import annofabapi
 import more_itertools
 from annofabapi.models import (
     AnnotationSpecsHistory,
-    InputData,
     Inspection,
     OrganizationMember,
     ProjectMember,
@@ -33,8 +32,8 @@ class AddProps:
     """
 
     #: 組織メンバ一覧のキャッシュ
-    _organization_members: Optional[List[OrganizationMember]] = None
-    _project_member_list: Optional[List[ProjectMember]] = None
+    _organization_members: Optional[list[OrganizationMember]] = None
+    _project_member_list: Optional[list[ProjectMember]] = None
 
     def __init__(self, service: annofabapi.Resource, project_id: str) -> None:
         self.service = service
@@ -43,14 +42,12 @@ class AddProps:
         self._specs_labels: Optional[list[dict[str, Any]]] = None
         self._specs_inspection_phrases: Optional[list[dict[str, Any]]] = None
 
-    def _set_annotation_specs(self):
+    def _set_annotation_specs(self):  # noqa: ANN202
         """
         アノテーション仕様に関する情報をインスタンス変数に格納します。
         """
         annotation_specs, _ = self.service.api.get_annotation_specs(self.project_id, query_params={"v": "2"})
-        self._specs_labels = convert_annotation_specs_labels_v2_to_v1(
-            labels_v2=annotation_specs["labels"], additionals_v2=annotation_specs["additionals"]
-        )
+        self._specs_labels = convert_annotation_specs_labels_v2_to_v1(labels_v2=annotation_specs["labels"], additionals_v2=annotation_specs["additionals"])
         self._specs_inspection_phrases = annotation_specs["inspection_phrases"]
 
     @property
@@ -87,8 +84,8 @@ class AddProps:
         return millisecond / 1000 / 3600
 
     @staticmethod
-    def get_message(i18n_messages: Dict[str, Any], locale: MessageLocale) -> Optional[str]:
-        messages: List[Dict[str, Any]] = i18n_messages["messages"]
+    def get_message(i18n_messages: dict[str, Any], locale: MessageLocale) -> Optional[str]:
+        messages: list[dict[str, Any]] = i18n_messages["messages"]
         dict_message = more_itertools.first_true(messages, pred=lambda e: e["lang"] == locale.value)
         if dict_message is not None:
             return dict_message["message"]
@@ -96,7 +93,7 @@ class AddProps:
             return None
 
     @staticmethod
-    def add_properties_of_project(target: Dict[str, Any], project_title: str) -> Dict[str, Any]:
+    def add_properties_of_project(target: dict[str, Any], project_title: str) -> dict[str, Any]:
         target["project_title"] = project_title
         return target
 
@@ -117,9 +114,7 @@ class AddProps:
 
     def get_project_member_from_account_id(self, account_id: str) -> Optional[ProjectMember]:
         if self._project_member_list is None:
-            project_member_list = self.service.wrapper.get_all_project_members(
-                self.project_id, query_params={"include_inactive_member": True}
-            )
+            project_member_list = self.service.wrapper.get_all_project_members(self.project_id, query_params={"include_inactive_member": True})
             self._project_member_list = project_member_list
         else:
             project_member_list = self._project_member_list
@@ -134,9 +129,7 @@ class AddProps:
         return organization["organization_name"]
 
     def get_phrase_name(self, phrase_id: str, locale: MessageLocale) -> Optional[str]:
-        phrase: Optional[Dict[str, Any]] = more_itertools.first_true(
-            self.specs_inspection_phrases, pred=lambda e: e["id"] == phrase_id
-        )
+        phrase: Optional[dict[str, Any]] = more_itertools.first_true(self.specs_inspection_phrases, pred=lambda e: e["id"] == phrase_id)
         if phrase is None:
             return None
 
@@ -149,10 +142,8 @@ class AddProps:
 
         return self.get_message(label["label_name"], locale)
 
-    def get_additional_data_name(
-        self, additional_data_definition_id: str, locale: MessageLocale, label_id: Optional[str] = None
-    ) -> Optional[str]:
-        def _get_additional_data_name(arg_additional_data_definitions: List[Dict[str, Any]]) -> Optional[str]:
+    def get_additional_data_name(self, additional_data_definition_id: str, locale: MessageLocale, label_id: Optional[str] = None) -> Optional[str]:
+        def _get_additional_data_name(arg_additional_data_definitions: list[dict[str, Any]]) -> Optional[str]:
             additional_data = more_itertools.first_true(
                 arg_additional_data_definitions,
                 pred=lambda e: e["additional_data_definition_id"] == additional_data_definition_id,
@@ -175,9 +166,7 @@ class AddProps:
 
             return None
 
-    def add_properties_to_annotation_specs_history(
-        self, annotation_specs_history: AnnotationSpecsHistory
-    ) -> AnnotationSpecsHistory:
+    def add_properties_to_annotation_specs_history(self, annotation_specs_history: AnnotationSpecsHistory) -> AnnotationSpecsHistory:
         """
         アノテーション仕様の履歴に、以下のキーを追加する.
         user_id
@@ -205,9 +194,7 @@ class AddProps:
         """
         return self._add_user_info(instruction_history)
 
-    def add_properties_to_inspection(
-        self, inspection: Inspection, detail: Optional[Dict[str, Any]] = None
-    ) -> Inspection:
+    def add_properties_to_inspection(self, inspection: Inspection, detail: Optional[dict[str, Any]] = None) -> Inspection:
         """
         検査コメントに、以下のキーを追加する.
         commenter_user_id
@@ -225,7 +212,7 @@ class AddProps:
 
         """
 
-        def add_commenter_info():
+        def add_commenter_info():  # noqa: ANN202
             commenter_user_id = None
             commenter_username = None
 
@@ -251,7 +238,7 @@ class AddProps:
 
         return inspection
 
-    def add_properties_to_comment(self, comment: Dict[str, Any]) -> Dict[str, Any]:
+    def add_properties_to_comment(self, comment: dict[str, Any]) -> dict[str, Any]:
         """
         検査コメントに、以下のキーを追加する.
         user_id
@@ -268,7 +255,7 @@ class AddProps:
 
         """
 
-        def add_commenter_info():
+        def add_commenter_info():  # noqa: ANN202
             commenter_user_id = None
             commenter_username = None
 
@@ -382,37 +369,16 @@ class AddProps:
         task_history["worktime_hour"] = isoduration_to_hour(task_history["accumulated_labor_time_milliseconds"])
         return task_history
 
-    def add_properties_to_task_history_event(self, task_history_event: Dict[str, Any]) -> Dict[str, Any]:
+    def add_properties_to_task_history_event(self, task_history_event: dict[str, Any]) -> dict[str, Any]:
         """
         タスク履歴イベント情報に、以下のキーを追加する.
 
         * user_id
         * username
-
-        Args:
-            task:
-
-        Returns:
-            Task情報
+        * request.user_id
+        * request.username
 
         """
         self._add_user_info(task_history_event)
+        self._add_user_info(task_history_event["request"])
         return task_history_event
-
-    @staticmethod
-    def add_properties_to_input_data(input_data: InputData, task_id_list: List[str]) -> InputData:
-        """
-        入力データ情報に、以下のキーを追加する。
-
-        * parent_task_id_list
-
-        Args:
-            input_data:
-            task_id_list:
-
-        Returns:
-            入力データ情報
-
-        """
-        input_data["parent_task_id_list"] = task_id_list
-        return input_data
