@@ -3,8 +3,9 @@ import json
 import logging
 import sys
 import zipfile
+from collections.abc import Collection, Iterator
 from pathlib import Path
-from typing import Any, Callable, Collection, Dict, Iterator, List, Optional, Set
+from typing import Any, Callable, Optional
 
 from annofabapi.parser import (
     SimpleAnnotationDirParser,
@@ -17,8 +18,8 @@ from annofabapi.parser import (
 import annofabcli
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
-    AbstractCommandLineWithoutWebapiInterface,
     ArgumentParser,
+    CommandLineWithoutWebapi,
     get_list_from_args,
 )
 
@@ -40,7 +41,7 @@ class MergeAnnotationMain:
             raise RuntimeError(f"{annotation_path} はサポート対象外です。")
 
     @staticmethod
-    def _write_outer_file(parser: SimpleAnnotationParser, anno: Dict[str, Any], output_json: Path):
+    def _write_outer_file(parser: SimpleAnnotationParser, anno: dict[str, Any], output_json: Path) -> None:
         data_uri = anno["data"]["data_uri"]
 
         with parser.open_outer_file(data_uri) as src_f:
@@ -51,12 +52,10 @@ class MergeAnnotationMain:
                 dest_f.write(data)
 
     @staticmethod
-    def _is_segmentation(anno: Dict[str, Any]):
+    def _is_segmentation(anno: dict[str, Any]) -> bool:
         return anno["data"]["_type"] in ["Segmentation", "SegmentationV2"]
 
-    def write_merged_annotation(
-        self, parser1: SimpleAnnotationParser, parser2: SimpleAnnotationParser, output_json: Path
-    ):
+    def write_merged_annotation(self, parser1: SimpleAnnotationParser, parser2: SimpleAnnotationParser, output_json: Path):  # noqa: ANN201
         simple_annotation1 = parser1.load_json()
         simple_annotation2 = parser2.load_json()
         details1 = simple_annotation1["details"]
@@ -80,9 +79,7 @@ class MergeAnnotationMain:
             merged_details.append(new_anno)
             # 塗りつぶしアノテーションファイルをコピーする
             if self._is_segmentation(new_anno):
-                self._write_outer_file(
-                    parser=(parser2 if adopt_two else parser1), anno=new_anno, output_json=output_json
-                )
+                self._write_outer_file(parser=(parser2 if adopt_two else parser1), anno=new_anno, output_json=output_json)
 
         merged_details.extend(list(details2_dict.values()))
 
@@ -96,10 +93,10 @@ class MergeAnnotationMain:
         }
 
         output_json.parent.mkdir(parents=True, exist_ok=True)
-        with output_json.open("w") as f:
+        with output_json.open("w", encoding="utf-8") as f:
             json.dump(new_simple_annotation, f, ensure_ascii=False)
 
-    def copy_annotation(self, parser: SimpleAnnotationParser, output_json: Path):
+    def copy_annotation(self, parser: SimpleAnnotationParser, output_json: Path):  # noqa: ANN201
         simple_annotation = parser.load_json()
         details = simple_annotation["details"]
 
@@ -109,13 +106,11 @@ class MergeAnnotationMain:
                 self._write_outer_file(parser, anno, output_json)
 
         output_json.parent.mkdir(exist_ok=True, parents=True)
-        with output_json.open("w") as f:
+        with output_json.open("w", encoding="utf-8") as f:
             json.dump(simple_annotation, f, ensure_ascii=False)
 
     @staticmethod
-    def _get_parser(
-        annotation_path: Path, zip_file: Optional[zipfile.ZipFile], json_path: Path
-    ) -> Optional[SimpleAnnotationParser]:
+    def _get_parser(annotation_path: Path, zip_file: Optional[zipfile.ZipFile], json_path: Path) -> Optional[SimpleAnnotationParser]:
         if annotation_path.is_dir():
             if (annotation_path / json_path).exists():
                 return SimpleAnnotationDirParser(annotation_path / json_path)
@@ -139,7 +134,7 @@ class MergeAnnotationMain:
         task_id_set = set(task_ids) if task_ids is not None else None
 
         def is_target_parser(parser: SimpleAnnotationParser) -> bool:
-            if task_id_set is not None and len(task_id_set) > 0:
+            if task_id_set is not None and len(task_id_set) > 0:  # noqa: SIM102
                 if parser.task_id not in task_id_set:
                     return False
 
@@ -147,7 +142,7 @@ class MergeAnnotationMain:
 
         return is_target_parser
 
-    def main(
+    def main(  # noqa: ANN201
         self,
         annotation_path1: Path,
         annotation_path2: Path,
@@ -162,7 +157,7 @@ class MergeAnnotationMain:
         if annotation_path2.is_file():
             zip_file2 = zipfile.ZipFile(str(annotation_path2), "r")  # pylint: disable=consider-using-with
 
-        excluded_json_path2: Set[str] = set()
+        excluded_json_path2: set[str] = set()
         for parser1 in iter_parser1:
             if is_target_parser_func is not None and not is_target_parser_func(parser1):
                 continue
@@ -199,38 +194,36 @@ class MergeAnnotationMain:
             logger.debug(f"{output_json} を出力しました。")
 
 
-class MergeAnnotation(AbstractCommandLineWithoutWebapiInterface):
+class MergeAnnotation(CommandLineWithoutWebapi):
     @staticmethod
     def validate(args: argparse.Namespace) -> bool:
-        COMMON_MESSAGE = "annofabcli filesystem merge_annotation: error:"
+        COMMON_MESSAGE = "annofabcli filesystem merge_annotation: error:"  # noqa: N806
         if args.annotation is not None:
-            annotation_paths: List[Path] = args.annotation
+            annotation_paths: list[Path] = args.annotation
             for path in annotation_paths:
                 if not path.exists():
-                    print(
+                    print(  # noqa: T201
                         f"{COMMON_MESSAGE} argument --annotation: ファイルパス '{path}' が存在しません。",
                         file=sys.stderr,
                     )
                     return False
         return True
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
         if not self.validate(args):
             sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
         main_obj = MergeAnnotationMain()
         target_task_ids = get_list_from_args(args.task_id) if args.task_id is not None else None
-        main_obj.main(
-            args.annotation[0], args.annotation[1], output_dir=args.output_dir, target_task_ids=target_task_ids
-        )
+        main_obj.main(args.annotation[0], args.annotation[1], output_dir=args.output_dir, target_task_ids=target_task_ids)
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     MergeAnnotation(args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     parser.add_argument(
@@ -238,22 +231,20 @@ def parse_args(parser: argparse.ArgumentParser):
         type=Path,
         nargs=2,
         required=True,
-        help="AnnoFabからダウンロードしたアノテーションzip、またはzipを展開したディレクトリを2つ指定してください。",
+        help="Annofabからダウンロードしたアノテーションzip、またはzipを展開したディレクトリを2つ指定してください。",
     )
 
     parser.add_argument("-o", "--output_dir", type=Path, required=True, help="出力先ディレクトリ")
 
     argument_parser.add_task_id(
         required=False,
-        help_message=(
-            "マージ対象であるタスクのtask_idを指定します。" "指定しない場合、すべてのタスクがマージ対象です。" " ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。"
-        ),
+        help_message=("マージ対象であるタスクのtask_idを指定します。指定しない場合、すべてのタスクがマージ対象です。 ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。"),
     )
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "merge_annotation"
 
     subcommand_help = "2つのアノテーションzip（またはzipを展開したディレクトリ）をマージします。"
