@@ -5,13 +5,13 @@ import datetime
 import logging
 from collections import defaultdict
 from pathlib import Path
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Optional
 
 import pandas
 from dateutil.parser import parse
 
 import annofabcli
-from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
+from annofabcli.common.cli import ArgumentParser, CommandLine, build_annofabapi_resource_and_login
 from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.task_history_event.list_worktime import (
     ListWorktimeFromTaskHistoryEventMain,
@@ -20,7 +20,7 @@ from annofabcli.task_history_event.list_worktime import (
 
 logger = logging.getLogger(__name__)
 
-WorktimeDict = Dict[Tuple[str, str, str], float]
+WorktimeDict = dict[tuple[str, str, str], float]
 """key: date, account_id, phase"""
 
 
@@ -39,9 +39,7 @@ def _get_worktime_dict_from_event(event: WorktimeFromTaskHistoryEvent) -> Workti
 
         while dt_tmp_start.date() < dt_end.date():
             dt_next_date = dt_tmp_start.date() + datetime.timedelta(days=1)
-            dt_tmp_end = datetime.datetime(
-                year=dt_next_date.year, month=dt_next_date.month, day=dt_next_date.day, tzinfo=jst_tzinfo
-            )
+            dt_tmp_end = datetime.datetime(year=dt_next_date.year, month=dt_next_date.month, day=dt_next_date.day, tzinfo=jst_tzinfo)
             worktime_hour = (dt_tmp_end - dt_tmp_start).total_seconds() / 3600
             dict_result[(str(dt_tmp_start.date()), event.account_id, event.phase)] = worktime_hour
             dt_tmp_start = dt_tmp_end
@@ -62,9 +60,7 @@ def get_worktime_dict_from_event_list(task_history_event_list: list[WorktimeFrom
     return dict_result
 
 
-def get_df_worktime(
-    task_history_event_list: list[WorktimeFromTaskHistoryEvent], member_list: list[dict[str, Any]]
-) -> pandas.DataFrame:
+def get_df_worktime(task_history_event_list: list[WorktimeFromTaskHistoryEvent], member_list: list[dict[str, Any]]) -> pandas.DataFrame:
     dict_worktime = get_worktime_dict_from_event_list(task_history_event_list)
 
     s = pandas.Series(
@@ -88,13 +84,9 @@ def get_df_worktime(
         if column not in df.columns:
             df[column] = 0
 
-    df.fillna(
-        {"annotation_worktime_hour": 0, "inspection_worktime_hour": 0, "acceptance_worktime_hour": 0}, inplace=True
-    )
+    df.fillna({"annotation_worktime_hour": 0, "inspection_worktime_hour": 0, "acceptance_worktime_hour": 0}, inplace=True)
 
-    df["worktime_hour"] = (
-        df["annotation_worktime_hour"] + df["inspection_worktime_hour"] + df["acceptance_worktime_hour"]
-    )
+    df["worktime_hour"] = df["annotation_worktime_hour"] + df["inspection_worktime_hour"] + df["acceptance_worktime_hour"]
 
     df_member = pandas.DataFrame(member_list)[["account_id", "user_id", "username", "biography"]]
 
@@ -114,12 +106,12 @@ def get_df_worktime(
     ]
 
 
-class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
+class ListWorktimeFromTaskHistoryEvent(CommandLine):
     def print_worktime_list(
         self,
         project_id: str,
         task_history_event_json: Optional[Path],
-    ):
+    ) -> None:
         super().validate_project(project_id, project_member_roles=None)
 
         main_obj = ListWorktimeFromTaskHistoryEventMain(self.service, project_id=project_id)
@@ -127,18 +119,15 @@ class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
             project_id,
             task_history_event_json=task_history_event_json,
         )
-        project_member_list = self.service.wrapper.get_all_project_members(
-            project_id, query_params={"include_inactive_member": ""}
-        )
+        project_member_list = self.service.wrapper.get_all_project_members(project_id, query_params={"include_inactive_member": ""})
         df = get_df_worktime(worktime_list, project_member_list)
 
         if len(worktime_list) > 0:
             self.print_csv(df)
         else:
             logger.warning("データ件数が0件であるため、出力しません。")
-            return
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
 
         self.print_worktime_list(
@@ -147,13 +136,13 @@ class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
         )
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     ListWorktimeFromTaskHistoryEvent(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
@@ -167,12 +156,11 @@ def parse_args(parser: argparse.ArgumentParser):
     )
 
     argument_parser.add_output()
-    argument_parser.add_csv_format()
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "list_worktime"
     subcommand_help = "日ごとユーザごとの作業時間の一覧を出力します。"
     description = "タスク履歴イベント全件ファイルから、日ごとユーザごとの作業時間の一覧を出力します。"
