@@ -4,7 +4,7 @@ import argparse
 import json
 import logging
 from enum import Enum
-from typing import List, Optional
+from typing import Optional
 
 import pandas
 from annofabapi.models import ProjectMemberRole, Task, TaskPhase, TaskStatus
@@ -12,11 +12,10 @@ from annofabapi.models import ProjectMemberRole, Task, TaskPhase, TaskStatus
 import annofabcli
 import annofabcli.common.cli
 from annofabcli.common.cli import (
-    AbstractCommandLineInterface,
     ArgumentParser,
+    CommandLine,
     build_annofabapi_resource_and_login,
     get_json_from_args,
-    get_wait_options_from_args,
 )
 from annofabcli.common.dataclasses import WaitOptions
 from annofabcli.common.download import DownloadingFile
@@ -98,9 +97,7 @@ def get_task_id_prefix(task_id: str, delimiter: str) -> str:
         return delimiter.join(tmp_list[0 : len(tmp_list) - 1])
 
 
-def create_task_count_summary_df(
-    task_list: List[Task], task_id_delimiter: Optional[str], task_id_groups: Optional[dict[str, list[str]]]
-) -> pandas.DataFrame:
+def create_task_count_summary_df(task_list: list[Task], task_id_delimiter: Optional[str], task_id_groups: Optional[dict[str, list[str]]]) -> pandas.DataFrame:
     """
     タスク数を集計したDataFrameを生成する。
 
@@ -111,7 +108,7 @@ def create_task_count_summary_df(
 
     """
 
-    def add_columns_if_not_exists(df: pandas.DataFrame, column: str):
+    def add_columns_if_not_exists(df: pandas.DataFrame, column: str):  # noqa: ANN202
         if column not in df.columns:
             df[column] = 0
 
@@ -122,11 +119,7 @@ def create_task_count_summary_df(
 
     if task_id_groups is not None:
         df_tmp = pandas.DataFrame(
-            [
-                (task_id_group, task_id)
-                for task_id_group, task_id_list in task_id_groups.items()
-                for task_id in task_id_list
-            ],
+            [(task_id_group, task_id) for task_id_group, task_id_list in task_id_groups.items() for task_id in task_id_list],
             columns=("task_id_group", "task_id"),
         )
         df_task = df_task.merge(df_tmp, on="task_id", how="left")
@@ -134,32 +127,25 @@ def create_task_count_summary_df(
     if task_id_delimiter is not None:
         df_task["task_id_group"] = df_task["task_id"].map(lambda e: get_task_id_prefix(e, delimiter=task_id_delimiter))
 
-    df_task["task_id_group"].fillna(TASK_ID_GROUP_UNKNOWN, inplace=True)
+    df_task.fillna({"task_id_group": TASK_ID_GROUP_UNKNOWN}, inplace=True)
 
-    df_summary = df_task.pivot_table(
-        values="task_id", index=["task_id_group"], columns=["status_for_summary"], aggfunc="count", fill_value=0
-    ).reset_index()
+    df_summary = df_task.pivot_table(values="task_id", index=["task_id_group"], columns=["status_for_summary"], aggfunc="count", fill_value=0).reset_index()
 
     for status in TaskStatusForSummary:
         add_columns_if_not_exists(df_summary, status.value)
 
-    df_summary["sum"] = (
-        df_task.pivot_table(values="task_id", index=["task_id_group"], aggfunc="count", fill_value=0)
-        .reset_index()
-        .fillna(0)["task_id"]
-    )
+    df_summary["sum"] = df_task.pivot_table(values="task_id", index=["task_id_group"], aggfunc="count", fill_value=0).reset_index().fillna(0)["task_id"]
 
     return df_summary
 
 
-class SummarizeTaskCountByTaskId(AbstractCommandLineInterface):
+class SummarizeTaskCountByTaskId(CommandLine):
     def print_summarize_task_count(self, df: pandas.DataFrame) -> None:
         columns = ["task_id_group"] + [status.value for status in TaskStatusForSummary] + ["sum"]
         annofabcli.common.utils.print_according_to_format(
             df[columns],
-            arg_format=FormatArgument(FormatArgument.CSV),
+            format=FormatArgument(FormatArgument.CSV),
             output=self.output,
-            csv_format=self.csv_format,
         )
 
     def main(self) -> None:
@@ -170,21 +156,16 @@ class SummarizeTaskCountByTaskId(AbstractCommandLineInterface):
         if args.task_json is not None:
             task_json_path = args.task_json
         else:
-            wait_options = get_wait_options_from_args(get_json_from_args(args.wait_options), DEFAULT_WAIT_OPTIONS)
             cache_dir = annofabcli.common.utils.get_cache_dir()
             task_json_path = cache_dir / f"{project_id}-task.json"
 
             downloading_obj = DownloadingFile(self.service)
-            downloading_obj.download_task_json(
-                project_id, dest_path=str(task_json_path), is_latest=args.latest, wait_options=wait_options
-            )
+            downloading_obj.download_task_json(project_id, dest_path=str(task_json_path), is_latest=args.latest, wait_options=DEFAULT_WAIT_OPTIONS)
 
-        with open(task_json_path, encoding="utf-8") as f:
+        with open(task_json_path, encoding="utf-8") as f:  # noqa: PTH123
             task_list = json.load(f)
 
-        df = create_task_count_summary_df(
-            task_list, task_id_delimiter=args.task_id_delimiter, task_id_groups=get_json_from_args(args.task_id_groups)
-        )
+        df = create_task_count_summary_df(task_list, task_id_delimiter=args.task_id_delimiter, task_id_groups=get_json_from_args(args.task_id_groups))
         self.print_summarize_task_count(df)
 
 
@@ -214,20 +195,11 @@ def parse_args(parser: argparse.ArgumentParser) -> None:
     )
 
     parser.add_argument(
-        "--latest", action="store_true", help="最新のタスク一覧ファイルを参照します。このオプションを指定すると、タスク一覧ファイルを更新するのに数分待ちます。"
+        "--latest",
+        action="store_true",
+        help="最新のタスク一覧ファイルを参照します。このオプションを指定すると、タスク一覧ファイルを更新するのに数分待ちます。",
     )
 
-    parser.add_argument(
-        "--wait_options",
-        type=str,
-        help="タスク一覧ファイルの更新が完了するまで待つ際のオプションを、JSON形式で指定してください。"
-        " ``file://`` を先頭に付けるとjsonファイルを指定できます。"
-        'デフォルは ``{"interval":60, "max_tries":360}`` です。'
-        " ``interval`` :完了したかを問い合わせる間隔[秒], "
-        "``max_tires`` :完了したかの問い合わせを最大何回行うか。",
-    )
-
-    argument_parser.add_csv_format()
     argument_parser.add_output()
 
     parser.set_defaults(subcommand_func=main)
